@@ -10,8 +10,14 @@ tarVersion = "V20210823"
 VersionDetail = "当前版本:" + tarVersion + """
 ---------------------------版本更新信息----------------------------
 
+可调用方法的API文档请访问:http://www.chuangfeigu.com:9900/web/#/60?page_id=1128
+
 V20210823:
 1.使用新的框架来实现旧的api
+
+V20220624:
+1、添加注释.
+
 ------------------------------------------------------------------
 """
 
@@ -70,63 +76,167 @@ class AgricultureDeviceDriver(BaseDriver):
             return False
 
     def setWaitTime(self, wait_recv_time=1):
+        """设置查询指令的响应等待时间.
+
+        Note:
+            该参数为全局变量.影响查询类方法的执行速度和成功率.
+            一般情况下,响应等待时间越久,执行速度越慢,成功率越高.
+            应根据实际的网络状况来谨慎配置.
+            不建议设置到0.5以下.
+
+        Args:
+            wait_recv_time (float, optional): 等待时间,单位:秒. Defaults to 1.
+
+        """
+        if wait_recv_time < 0:
+            LOGGER.logger.error(f"Parameter setting error!")
+            return False
         self.wait_time = wait_recv_time
 
     def getVersion(self):
+        """获取当前驱动的版本信息.
+
+        Returns:
+            Str: 当前驱动的版本号.
+        """
         return tarVersion
 
     def showVersion(self):
+        """打印历史版本的更新记录
+        """
         print(VersionDetail)
 
     ########################## 以下是大棚内的设备控制/查询方法 ############################
     # 补光灯
     def isLightOpen(self, moduleID=4):
+        """查询补光灯状态
+
+        Args:
+            moduleID (int, optional): 硬件接口号. Defaults to 4.
+
+        Returns:
+            Boolean: False:查询失败或未打开;True: 已打开.
+            
+        """
         return self.isSingleStatusTrueOrFalse(int(moduleID), 0x00AA)
         # return self.queryOrder(self.wait_time, "03号查询指令", int(moduleID), 0x00AA, 0x01, 0)
 
     def openLight(self, moduleID=4):
+        """打开补光灯
+
+        Args:
+            moduleID (int, optional): 硬件接口号. Defaults to 4.
+
+        """
         self.excuteOrderRightAway("10号写指令", int(moduleID), 0x00AA, 0x01, 0x02,
                                   0x0001, 0)
 
     def closeLight(self, moduleID=4):
+        """关闭补光灯
+
+        Args:
+            moduleID (int, optional): 硬件接口号. Defaults to 4.
+
+        """
         self.excuteOrderRightAway("10号写指令", int(moduleID), 0x00AA, 0x01, 0x02,
                                   0x0000, 0)
 
     # 通风
     def isRoomFanOpen(self, moduleID=3):
+        """查询通风状态
+
+        Args:
+            moduleID (int, optional): 硬件接口号. Defaults to 3.
+
+        Returns:
+            Boolean: False:查询失败或未打开;True: 已打开.
+            
+        """
         return self.isSingleStatusTrueOrFalse(int(moduleID), 0x00AC)
         # return self.queryOrder(self.wait_time, "03号查询指令", int(moduleID), 0x00AC, 0x01, 0)
 
     def openRoomFan(self, moduleID=3):
+        """打开通风
+
+        Args:
+            moduleID (int, optional): 硬件接口号. Defaults to 3.
+
+        """
         self.excuteOrderRightAway("10号写指令", int(moduleID), 0x00AC, 0x01, 0x02,
                                   0x0001, 0)
 
     def closeRoomFan(self, moduleID=3):
+        """关闭通风
+
+        Args:
+            moduleID (int, optional): 硬件接口号. Defaults to 3.
+
+        """
         self.excuteOrderRightAway("10号写指令", int(moduleID), 0x00AC, 0x01, 0x02,
                                   0x0000, 0)
 
     # 卷帘
     def currentTCurtainStatus(self, moduleID=1):
+        """查询卷帘状态
+
+        Args:
+            moduleID (int, optional): 硬件接口号. Defaults to 1.
+
+        Returns:
+            Boolean: False:查询失败或未打开;True: 已打开.
+            
+        """
         return self.isSingleStatusTrueOrFalse(int(moduleID), 0x00BC)
         # return self.queryOrder(self.wait_time, "03号查询指令", int(moduleID), 0x00BC, 0x01, 0)
 
     def openTCurtain(self, moduleID=1):
+        """打开卷帘
+
+        Args:
+            moduleID (int, optional): 硬件接口号. Defaults to 1.
+        """
         self.excuteOrderRightAway("10号写指令", int(moduleID), 0x00BC, 0x01, 0x02,
                                   0x0001, 0)
 
     def closeTCurtain(self, moduleID=1):
+        """关闭卷帘
+
+        Args:
+            moduleID (int, optional): 硬件接口号. Defaults to 1.
+        """
         self.excuteOrderRightAway("10号写指令", int(moduleID), 0x00BC, 0x01, 0x02,
                                   0x0000, 0)
 
     # 灌溉
     def isWaterOpen(self, moduleID=2):
+        """查询灌溉状态
+
+        Args:
+            moduleID (int, optional): 灌溉. Defaults to 2.
+
+        Returns:
+            Boolean: False:查询失败或未打开;True: 已打开.
+            
+        """
         return self.isSingleStatusTrueOrFalse(int(moduleID), 0x00BA)
         # return self.queryOrder(self.wait_time, "03号查询指令", int(moduleID), 0x00BA, 0x01, 0)
 
     def openWater(self, moduleID=2):
+        """打开灌溉
+
+        Args:
+            moduleID (int, optional): 硬件接口号. Defaults to 2.
+
+        """
         self.excuteOrderRightAway("10号写指令", int(moduleID), 0x00BA, 0x01, 0x02,
                                   0x0001, 0)
 
     def closeWater(self, moduleID=2):
+        """关闭灌溉
+
+        Args:
+            moduleID (int, optional): 硬件接口号. Defaults to 2.
+            
+        """
         self.excuteOrderRightAway("10号写指令", int(moduleID), 0x00BA, 0x01, 0x02,
                                   0x0000, 0)
