@@ -5,11 +5,13 @@ from .protocolHandler import *
 from . import LOGGER
 import time
 
-tarVersion = "V20210824"
+tarVersion = "V20220621"
 
 VersionDetail = "当前版本:" + tarVersion + """
 ---------------------------版本更新信息----------------------------
 
+可调用方法的API文档请访问:http://www.chuangfeigu.com:9900/web/#/54?page_id=1029
+
 V20210818:
 1.使用新的框架来实现旧的api，注意该版本并未实现节点号缺省功能
 
@@ -20,6 +22,21 @@ V20210824:
 1、修复了温湿度获取API显示错位:def getTemperatureHumidity(self, moduleID):
 2、修复了语音识别API未识别到时引发错误的BUG:def recognizeSpeech(self, moduleID):
 3、增加了识别一条新语句的方法：def recognizeNewSpeech(self, moduleID):
+
+V20220425:
+1、修复了RGB控制API入参错位BUG:
+    def setRGBRed(self, moduleID, redValue):
+    def setRGBGreen(self, moduleID, greenValue):
+    def setRGBBlue(self, moduleID, blueValue):
+2、修复了蜂鸣器控制API调用API入参错误BUG:def playSongBySongID(self, moduleID, songID):
+
+V20220427:
+1、添加了语音识别API识别失败时的回参:def recognizeSpeech(self, moduleID):
+2、添加了手势识别API识别失败时的回参:def checkGesture(self, moduleID):
+
+V20220621:
+1、添加注释.
+
 ------------------------------------------------------------------
 """
 
@@ -170,6 +187,7 @@ class GatewayDict():
 
 
 class GatewayDriver(BaseDriver, GatewayDict):
+
     def __init__(self, host="localhost", port=4001):
         super().__init__(host, port)
         self.addProtocol(K12ProtocolHandler())
@@ -220,7 +238,7 @@ class GatewayDriver(BaseDriver, GatewayDict):
         self.connector.sendData(self.getClientId(), data, prior=False)
 
     # 单参数状态获取返回为true or false
-    def isSingleStatusTrueOrFalse(self, moduleID=None, moduleAddr=0):
+    def isSingleStatusTrueOrFalse(self, moduleID, moduleAddr=0):
         recv_buf = self.queryOrder(self.wait_time, "03号查询指令", int(moduleID),
                                    moduleAddr, 0x01, 0)
         if recv_buf is not None:
@@ -232,38 +250,85 @@ class GatewayDriver(BaseDriver, GatewayDict):
             return False
 
     def setWaitTime(self, wait_recv_time=1):
+        """设置查询指令的响应等待时间.
+
+        Note:
+            该参数为全局变量.影响查询类方法的执行速度和成功率.
+            一般情况下,响应等待时间越久,执行速度越慢,成功率越高.
+            应根据实际的网络状况来谨慎配置.
+            不建议设置到0.5以下.
+
+        Args:
+            wait_recv_time (float, optional): 等待时间,单位:秒. Defaults to 1.
+
+        """
+        if wait_recv_time < 0:
+            LOGGER.logger.error(f"Parameter setting error!")
+            return False
         self.wait_time = wait_recv_time
 
     def getVersion(self):
+        """获取当前驱动的版本信息.
+
+        Returns:
+            Str: 当前驱动的版本号.
+        """
         return tarVersion
 
     def showVersion(self):
+        """打印历史版本的更新记录.
+        """
         print(VersionDetail)
 
     ########################## 以下是网关节点配置方法 ############################
     def isSpeechAutoMode(self):
+        """查询联动开关状态.
+
+        Returns:
+            Boolean: False:查询失败/联动开关未开启;True:联动开关已开启.
+        """
         return self.isSingleStatusTrueOrFalse(int(255), 0xff03)
 
-    # 使能语音联动开关
     def enableSpeechAutoMode(self):
+        """使能语音联动开关.
+        """
         self.excuteOrderRightAway("10号写指令", int(255), 0xff03, 0x01, 0x02, 1, 0)
 
-    # 失能语音联动开关
     def disableSpeechAutoMode(self):
+        """失能语音联动开关.
+        """
         self.excuteOrderRightAway("10号写指令", int(255), 0xff03, 0x01, 0x02, 0, 0)
 
     ########################## 以下是通用的执行器控制方法 ############################
     # 风扇
     def openFan(self, moduleID):
+        """打开风扇.
+
+        Args:
+            moduleID (int): 硬件接口号.
+        """
         self.excuteOrderRightAway("10号写指令", int(moduleID), 0x0048, 0x01, 0x02,
                                   1, 0)
 
     def closeFan(self, moduleID):
+        """关闭风扇.
+
+        Args:
+            moduleID (int): 硬件接口号.
+        """
         self.excuteOrderRightAway("10号写指令", int(moduleID), 0x0048, 0x01, 0x02,
                                   0, 0)
 
     # RGB灯
     def openRGBLight(self, moduleID, redValue, greenValue, blueValue):
+        """控制RGB灯.
+
+        Args:
+            moduleID (int): 硬件接口号.
+            redValue (int): 红色亮度值(0~255),0为关闭.
+            greenValue (int): 绿色亮度值(0~255),0为关闭.
+            blueValue (int): 蓝色亮度值(0~255),0为关闭.
+        """
         self.excuteOrderRightAway("10号写指令", int(moduleID), 0x009e, 0x03, 0x06,
                                   ((int(redValue) & 0xFF) << 32) |
                                   ((int(greenValue) & 0xFF) << 16) |
@@ -273,21 +338,51 @@ class GatewayDriver(BaseDriver, GatewayDict):
     # def setRGBLight(self, redValue=None, greenValue=None, blueValue=None):
     #     self.openRGBLight(self, moduleID, redValue, greenValue, blueValue)
 
-    def setRGBRed(self, redValue, moduleID):
+    def setRGBRed(self, moduleID, redValue):
+        """控制RGB灯亮红色.
+
+        Args:
+            moduleID (int): 硬件接口号.
+            redValue (int): 红色亮度值(0~255),0为关闭.
+        """
         self.openRGBLight(moduleID, redValue, 0, 0)
 
-    def setRGBGreen(self, greenValue, moduleID):
+    def setRGBGreen(self, moduleID, greenValue):
+        """控制RGB灯亮绿色.
+
+        Args:
+            moduleID (int): 硬件接口号.
+            redValue (int): 绿色亮度值(0~255),0为关闭.
+        """
         self.openRGBLight(moduleID, 0, greenValue, 0)
 
-    def setRGBBlue(self, blueValue, moduleID):
+    def setRGBBlue(self, moduleID, blueValue):
+        """控制RGB灯亮蓝色.
+
+        Args:
+            moduleID (int): 硬件接口号.
+            redValue (int): 蓝色亮度值(0~255),0为关闭.
+        """
         self.openRGBLight(moduleID, 0, 0, blueValue)
 
-    def closeRGBLight(self, moduleID=None):
+    def closeRGBLight(self, moduleID):
+        """关闭RGB灯.
+
+        Args:
+            moduleID (int): 硬件接口号.
+        """
         self.excuteOrderRightAway("10号写指令", int(moduleID), 0x009e, 0x03, 0x06,
                                   0, 0)
 
     # 蜂鸣器
     def playAudioPlayer(self, moduleID, songID=1, songVolume=100):
+        """控制蜂鸣器.
+
+        Args:
+            moduleID (int): 硬件接口号.
+            songID (int, optional): 歌曲编号:范围(1~5). Defaults to 1.
+            songVolume (int, optional): 音量:范围(0~100). Defaults to 100.
+        """
         if songID != None and songVolume != None:
             if songID <= 0 or songID > 5 or songVolume < 0 or songVolume > 100:
                 return
@@ -297,40 +392,77 @@ class GatewayDriver(BaseDriver, GatewayDict):
                                   ((int(songID) << 16) | (int(songVolume))), 0)
 
     def playSongBySongID(self, moduleID, songID):
-        self.playAudioPlayer(int(moduleID), int(songID), 100, 0)
+        """控制蜂鸣器播放乐曲.
+        默认音量为100.
+        Args:
+            moduleID (int): 硬件接口号.
+            songID (int): 歌曲编号:范围(1~5). 
+        """
+        self.playAudioPlayer(int(moduleID), int(songID), 100)
 
     # todo
     # def playSong(self, songID, songVolumn):
     #     self.playAudioPlayer(None, songID, songVolumn)
 
     def stopAudioPlayer(self, moduleID):
+        """关闭蜂鸣器.
+
+        Args:
+            moduleID (int): 硬件接口号.
+        """
         self.excuteOrderRightAway("10号写指令", int(moduleID), 0x0096, 0x02, 0x04,
                                   0x00000000, 0)
 
     # 红外转发
     def sendIRTrans(self, moduleID, param):
+        """红外转发
+
+        Args:
+            moduleID (int): 硬件接口号.
+            param (int): 红外遥控编码:(0:OK功能;1-6:频道1-6;10-11;频道+，频道－;12-13:声音－,声音＋).
+        """
         param = param % 14
         if param in [7, 8, 9]:
             return
         self.excuteOrderRightAway("10号写指令", int(moduleID), 0x009A, 0x01, 0x02,
                                   param, 0)
 
-    def addChannel(self, moduleID=None):
+    def addChannel(self, moduleID):
+        """频道增加.
+
+        Args:
+            moduleID (int): 硬件接口号.
+        """
         param = 10
         self.excuteOrderRightAway("10号写指令", int(moduleID), 0x009A, 0x01, 0x02,
                                   param, 0)
 
-    def descChannel(self, moduleID=None):
+    def descChannel(self, moduleID):
+        """频道减小.
+
+        Args:
+            moduleID (int): 硬件接口号.
+        """
         param = 11
         self.excuteOrderRightAway("10号写指令", int(moduleID), 0x009A, 0x01, 0x02,
                                   param, 0)
 
-    def addVolumn(self, moduleID=None):
+    def addVolumn(self, moduleID):
+        """音量增加.
+
+        Args:
+            moduleID (int): 硬件接口号.
+        """
         param = 13
         self.excuteOrderRightAway("10号写指令", int(moduleID), 0x009A, 0x01, 0x02,
                                   param, 0)
 
-    def descVolumn(self, moduleID=None):
+    def descVolumn(self, moduleID):
+        """音量减小.
+
+        Args:
+            moduleID (int): 硬件接口号.
+        """
         param = 12
         self.excuteOrderRightAway("10号写指令", int(moduleID), 0x009A, 0x01, 0x02,
                                   param, 0)
@@ -339,24 +471,56 @@ class GatewayDriver(BaseDriver, GatewayDict):
 
     # 手势
     def checkGesture(self, moduleID):
+        """识别手势.
+
+        Args:
+            moduleID (int): 硬件接口号.
+
+        Returns:
+            Int或Boolen: Boolean: False:查询失败;查询成功返回识别到的语音编码.手势编码可参考字典gestureEncode.
+        """
         recv_buf = self.queryOrder(self.wait_time, "03号查询指令", int(moduleID),
                                    0x00A6, 0x01, 0)
         if recv_buf is not None:
-            return self.gestureEncode[recv_buf["data"]["数据"]]
+            current_gesture = recv_buf["data"]["数据"]
+            if current_gesture in self.gestureEncode:
+                return current_gesture
+            else:
+                return False
         else:
             return False
 
     # 语音识别
     def recognizeSpeech(self, moduleID):
+        """语音识别.
+
+        Args:
+            moduleID (int): 硬件接口号. 
+
+        Returns:
+            Int或Boolen: Boolean: False:查询失败;查询成功返回识别到的语音编码.Int: 语音编码可参考字典voiceEncodeV2.
+        
+        """
         recv_buf = self.queryOrder(self.wait_time, "03号查询指令", int(moduleID),
                                    0x00b8, 0x01, 0)
         if recv_buf is not None:
             current_speech = recv_buf["data"]["数据"]
             if current_speech in self.voiceEncodeV2:
                 return current_speech
+            else:
+                return False
         return False
 
     def recognizeNewSpeech(self, moduleID):
+        """识别新语句.
+
+        Args:
+            moduleID (int): 硬件接口号.
+
+        Returns:
+            Int或Boolen: Boolean: False:查询失败或查询的语句未改变;Int: 查询到新语句返回识别到的语音编码.语音编码可参考字典voiceEncodeV2.
+        
+        """
         recv_buf = self.recognizeSpeech(moduleID)
         if recv_buf is not False and recv_buf != self.last_speech:
             self.last_speech = recv_buf
@@ -365,6 +529,14 @@ class GatewayDriver(BaseDriver, GatewayDict):
 
     # 场景代码-红外对射场景
     def getIRDegree(self, moduleID):
+        """获取红外对射状态.
+
+        Args:
+            moduleID (int): 硬件接口号.
+
+        Returns:
+            Boolean: False:查询失败或未触发;True: 已触发.
+        """
         recv_buf = self.queryOrder(self.wait_time, "03号查询指令", int(moduleID),
                                    0x002C, 0x01, 0)
         if recv_buf is not None:
@@ -377,6 +549,14 @@ class GatewayDriver(BaseDriver, GatewayDict):
 
     # 场景代码-红外反射传感器
     def getAIRDegree(self, moduleID):
+        """获取红外反射状态.
+
+        Args:
+            moduleID (int): 硬件接口号.
+
+        Returns:
+            Boolean: False:查询失败或未触发;True: 已触发.
+        """
         recv_buf = self.queryOrder(self.wait_time, "03号查询指令", int(moduleID),
                                    0x0036, 0x01, 0)
         if recv_buf is not None:
@@ -389,6 +569,14 @@ class GatewayDriver(BaseDriver, GatewayDict):
 
     # 场景代码-红外转发
     def getIRSend(self, moduleID):
+        """获取红外转发状态.
+
+        Args:
+            moduleID (int): 硬件接口号.
+
+        Returns:
+            Int或Boolen:Boolean: False:查询失败;Int: 返回发送的红外遥控编码:(0:OK功能;1-6:频道1-6;10-11;频道+，频道－;12-13:声音－,声音＋).
+        """
         recv_buf = self.queryOrder(self.wait_time, "03号查询指令", int(moduleID),
                                    0x009A, 0x01, 0)
         if recv_buf is not None:
@@ -398,6 +586,14 @@ class GatewayDriver(BaseDriver, GatewayDict):
 
     # 场景代码-红外接收
     def getIRRecv(self, moduleID):
+        """获取红外接收状态.
+
+        Args:
+            moduleID (int): 硬件接口号.
+
+        Returns:
+            Int或Boolen:Boolean: False:查询失败;Int: 返回接收的红外遥控编码:(0:OK功能;1-6:频道1-6;10-11;频道+，频道－;12-13:声音－,声音＋).
+        """
         recv_buf = self.queryOrder(self.wait_time, "03号查询指令", int(moduleID),
                                    0x009C, 0x01, 0)
         if recv_buf is not None:
@@ -407,6 +603,14 @@ class GatewayDriver(BaseDriver, GatewayDict):
 
     # 场景代码-人体
     def checkHuman(self, moduleID):
+        """获取人体传感器状态.
+
+        Args:
+            moduleID (int): 硬件接口号.
+
+        Returns:
+            Boolean: False:查询失败或未触发;True: 已触发.
+        """
         recv_buf = self.queryOrder(self.wait_time, "03号查询指令", int(moduleID),
                                    0x003C, 0x01, 0)
         if recv_buf is not None:
@@ -419,6 +623,14 @@ class GatewayDriver(BaseDriver, GatewayDict):
 
     # 场景代码-获取光照值场景
     def getShineDegree(self, moduleID):
+        """获取光照数据.
+
+        Args:
+            moduleID (int): 硬件接口号.
+
+        Returns:
+            Int: 返回光照数据, 单位Lux; 0:查询失败.
+        """
         recv_buf = self.queryOrder(self.wait_time, "03号查询指令", int(moduleID),
                                    0x002A, 0x01, 0)
         if recv_buf is not None:
@@ -428,6 +640,14 @@ class GatewayDriver(BaseDriver, GatewayDict):
 
     # 场景代码-烟雾
     def checkSmoke(self, moduleID):
+        """获取烟雾数据.
+
+        Args:
+            moduleID (int): 硬件接口号.
+
+        Returns:
+            Int: 返回烟雾数据; 0:查询失败.
+        """
         recv_buf = self.queryOrder(self.wait_time, "03号查询指令", int(moduleID),
                                    0x0034, 0x01, 0)
         if recv_buf is not None:
@@ -437,6 +657,14 @@ class GatewayDriver(BaseDriver, GatewayDict):
 
     # 场景代码-声音
     def checkSound(self, moduleID):
+        """获取声音传感器状态.
+
+        Args:
+            moduleID (int): 硬件接口号.
+
+        Returns:
+            Boolean: False:查询失败或未触发;True: 已触发.
+        """
         recv_buf = self.queryOrder(self.wait_time, "03号查询指令", int(moduleID),
                                    0x003A, 0x01, 0)
         if recv_buf is not None:
@@ -449,6 +677,14 @@ class GatewayDriver(BaseDriver, GatewayDict):
 
     # 场景代码-结露
     def checkRain(self, moduleID):
+        """获取结露数据.
+
+        Args:
+            moduleID (int): 硬件接口号.
+
+        Returns:
+            Int: 返回结露数据; -1:查询失败.
+        """
         recv_buf = self.queryOrder(self.wait_time, "03号查询指令", int(moduleID),
                                    0x002E, 0x01, 0)
         if recv_buf is not None:
@@ -458,6 +694,14 @@ class GatewayDriver(BaseDriver, GatewayDict):
 
     # 场景代码-火焰
     def checkFire(self, moduleID):
+        """获取火焰传感器状态.
+
+        Args:
+            moduleID (int): 硬件接口号.
+
+        Returns:
+            Boolean: False:查询失败或未触发;True: 已触发.
+        """
         recv_buf = self.queryOrder(self.wait_time, "03号查询指令", int(moduleID),
                                    0x0038, 0x01, 0)
         if recv_buf is not None:
@@ -469,7 +713,15 @@ class GatewayDriver(BaseDriver, GatewayDict):
             return False
 
     # 场景代码-燃气
-    def checkCGas(self, moduleID=None):
+    def checkCGas(self, moduleID):
+        """获取燃气数据.
+
+        Args:
+            moduleID (int): 硬件接口号.
+
+        Returns:
+            Int: 返回燃气数据; -1:查询失败.
+        """
         recv_buf = self.queryOrder(self.wait_time, "03号查询指令", int(moduleID),
                                    0x00A4, 0x01, 0)
         if recv_buf is not None:
@@ -479,6 +731,17 @@ class GatewayDriver(BaseDriver, GatewayDict):
 
     # 场景代码-温湿度
     def getTemperatureHumidity(self, moduleID):
+        """查询温湿度
+
+        Args:
+            moduleID (int): 硬件接口号.
+
+        Returns:
+            List: 查询失败返回[-1,-1];查询成功返回[Temperature,Humidity]具体含义如下.
+            Temperature: 温度,单位°.
+            Humidity: 湿度,单位%.
+
+        """
         recv_buf = self.queryOrder(self.wait_time, "03号查询指令", int(moduleID),
                                    0x0014, 0x02, 0)
         if recv_buf is not None:
@@ -489,6 +752,15 @@ class GatewayDriver(BaseDriver, GatewayDict):
 
     # 场景代码-温度
     def getTemperature(self, moduleID):
+        """查询温度
+
+        Args:
+            moduleID (int): 硬件接口号.
+
+        Returns:
+            Int: 查询失败返回-1;查询成功返回温度值,单位°.
+
+        """
         recv_buf = self.getTemperatureHumidity(moduleID)
         if recv_buf[0] != -1 and recv_buf[1] != -1:
             return recv_buf[0]
@@ -497,6 +769,15 @@ class GatewayDriver(BaseDriver, GatewayDict):
 
     # 场景代码-湿度
     def getHumidity(self, moduleID):
+        """查询湿度
+
+        Args:
+            moduleID (int): 硬件接口号.
+
+        Returns:
+            Int: 查询失败返回-1;查询成功返回湿度值,单位%.
+
+        """
         recv_buf = self.getTemperatureHumidity(moduleID)
         if recv_buf[0] != -1 and recv_buf[1] != -1:
             return recv_buf[1]
@@ -506,6 +787,15 @@ class GatewayDriver(BaseDriver, GatewayDict):
     ################### 以下是执行器状态查询 #####################
 
     def isFanOpen(self, moduleID):
+        """获取风扇状态.
+
+        Args:
+            moduleID (int): 硬件接口号.
+
+        Returns:
+            Boolean: False:查询失败或未开启;True: 已开启.
+
+        """
         recv_buf = self.queryOrder(self.wait_time, "03号查询指令", int(moduleID),
                                    0x0048, 0x01, 0)
         if recv_buf is not None:
@@ -517,6 +807,15 @@ class GatewayDriver(BaseDriver, GatewayDict):
             return False
 
     def isRGBLightOpen(self, moduleID):
+        """获取灯光状态.
+
+        Args:
+            moduleID (int): 硬件接口号.
+
+        Returns:
+            Boolean: False:查询失败或未开启;True: 已开启.
+
+        """
         recv_buf = self.queryOrder(self.wait_time, "03号查询指令", int(moduleID),
                                    0x009e, 0x03, 0)
         if recv_buf is not None:
@@ -528,6 +827,18 @@ class GatewayDriver(BaseDriver, GatewayDict):
             return False
 
     def currentRGBLight(self, moduleID):
+        """查询RGB灯状态
+
+        Args:
+            moduleID (int): 硬件接口号.
+
+        Returns:
+            List: 查询失败返回[-1,-1,-1];查询成功返回[status1,status2,status3]具体含义如下.
+            status1: 红色值，范围(0~255).
+            status2: 绿色值，范围(0~255).
+            status2: 蓝色值，范围(0~255).
+
+        """
         recv_buf = self.queryOrder(self.wait_time, "03号查询指令", int(moduleID),
                                    0x009e, 0x03, 0)
         if recv_buf is not None:
@@ -538,20 +849,47 @@ class GatewayDriver(BaseDriver, GatewayDict):
             return [-1, -1, -1]
 
     def getRGBRed(self, moduleID):
+        """查询RGB灯的红色值.
+
+        Args:
+            moduleID (int): 硬件接口号. 
+
+        Returns:
+            Int: 查询失败返回-1;查询成功返回RGB灯的红色值.
+
+        """
         recv_buf = self.currentRGBLight(moduleID)
         if recv_buf[0] != -1 and recv_buf[1] != -1 and recv_buf[2] != -1:
             return recv_buf[0]
         else:
             return -1
 
-    def getRGBGreen(self, moduleID=None):
+    def getRGBGreen(self, moduleID):
+        """查询RGB灯的绿色值.
+
+        Args:
+            moduleID (int): 硬件接口号. 
+
+        Returns:
+            Int: 查询失败返回-1;查询成功返回RGB灯的绿色值.
+
+        """
         recv_buf = self.currentRGBLight(moduleID)
         if recv_buf[0] != -1 and recv_buf[1] != -1 and recv_buf[2] != -1:
             return recv_buf[1]
         else:
             return -1
 
-    def getRGBBlue(self, moduleID=None):
+    def getRGBBlue(self, moduleID):
+        """查询RGB灯的蓝色值.
+
+        Args:
+            moduleID (int): 硬件接口号. 
+
+        Returns:
+            Int: 查询失败返回-1;查询成功返回RGB灯的蓝色值.
+
+        """
         recv_buf = self.currentRGBLight(moduleID)
         if recv_buf[0] != -1 and recv_buf[1] != -1 and recv_buf[2] != -1:
             return recv_buf[2]
@@ -559,6 +897,17 @@ class GatewayDriver(BaseDriver, GatewayDict):
             return -1
 
     def audioPlayerCurrentPlayed(self, moduleID):
+        """查询蜂鸣器状态
+
+        Args:
+            moduleID (int): 硬件接口号.
+
+        Returns:
+            List: 查询失败返回[-1,-1];查询成功返回[songID,songVolume]具体含义如下.
+            songID (int): 歌曲编号:范围(1~5). Defaults to 1.
+            songVolume (int): 音量:范围(0~100). Defaults to 100.
+
+        """
         recv_buf = self.queryOrder(self.wait_time, "03号查询指令", int(moduleID),
                                    0x0096, 0x02, 0)
         if recv_buf is not None:
@@ -568,13 +917,31 @@ class GatewayDriver(BaseDriver, GatewayDict):
             return [-1, -1]
 
     def audioPlayerCurrentPlayedSong(self, moduleID):
+        """查询蜂鸣器播放的歌曲编号.
+
+        Args:
+            moduleID (int): 硬件接口号. 
+
+        Returns:
+            Int: 查询失败返回-1;查询成功返回蜂鸣器播放的歌曲编号.
+
+        """
         recv_buf = self.audioPlayerCurrentPlayed(moduleID)
         if recv_buf[0] != -1 and recv_buf[1] != -1:
             return recv_buf[0]
         else:
             return -1
 
-    def audioPlayerCurrentPlayedVolumn(self, moduleID=None):
+    def audioPlayerCurrentPlayedVolumn(self, moduleID):
+        """查询蜂鸣器的音量.
+
+        Args:
+            moduleID (int): 硬件接口号. 
+
+        Returns:
+            Int: 查询失败返回-1;查询成功返回蜂鸣器的音量.
+
+        """
         recv_buf = self.audioPlayerCurrentPlayed(moduleID)
         if recv_buf[0] != -1 and recv_buf[1] != -1:
             return recv_buf[1]
