@@ -24,6 +24,12 @@ V20220415:
 V20220718:
 1. 修复了语音识别编码字典(voiceEncodeV3)与硬件返回不匹配的BUG。
 
+V20220802:
+1. 添加了3个语音识别接口的控制方法:
+    def clearCachedSpeech(self, moduleID=2):
+    def setCachedSpeech(self, moduleID=2, speechNum=0):
+    def recognizeSpeechAndClearCache(self, moduleID=2):
+
 ------------------------------------------------------------------
 """
 
@@ -258,6 +264,60 @@ class GeneralDeviceDriver(BaseDriver, GeneralDeviceDict):
             return self.last_speech
         return -1
 
+    def setCachedSpeech(self, moduleID=2, speechNum=0):
+        """设置语音识别缓存语句编号
+
+        Args:
+            moduleID (int, optional): 硬件接口号. Defaults to 2.
+            speechNum (int, optional): 待设置的语句编号. Defaults to 0.
+
+        Returns:
+            Boolean: False:参数校验失败/设置返回校验后且未校验成功返回数据;True:设置返回校验后且校验成功.
+
+        Examples:
+            # 设置2号接口语音识别缓存的编号为0.
+            >>>driver.setCachedSpeech(2, 0)
+        """
+        if speechNum > 0xFF:
+            LOGGER.logger.error(f"Parameter setting error!")
+            return False
+        return self.excuteOrder(self.send_time, "10号写指令", int(moduleID),
+                                0x00B8, 0x01, 0x02,
+                                ((int(speechNum) & 0xFFFF)), 0)
+
+    def clearCachedSpeech(self, moduleID=2):
+        """设置语音识别缓存的语句编号为0
+
+        Args:
+            moduleID (int, optional): 硬件接口号. Defaults to 2.
+
+        Returns:
+            Boolean: False:参数校验失败/设置返回校验后且未校验成功返回数据;True:设置返回校验后且校验成功.
+
+        Examples:
+            # 设置2号接口语音识别缓存的编号为0.
+            >>>driver.clearCachedSpeech(2)
+        """
+        return self.setCachedSpeech(moduleID)
+
+    def recognizeSpeechAndClearCache(self, moduleID=2):
+        """语音识别然后清除缓存
+
+        Args:
+            moduleID (int, optional): 硬件接口号. Defaults to 2.
+
+        Returns:
+            Int: 查询失败返回-1;查询成功返回识别到的语音编码.语音编码可参考字典voiceEncodeV3.
+
+        Examples:
+            >>>print(driver.recognizeSpeechAndClearCache(2))
+            2
+        """
+        speech_num_cache = self.recognizeSpeech(moduleID)
+        if speech_num_cache != -1 and speech_num_cache != 0:
+            self.clearCachedSpeech(moduleID)
+        return speech_num_cache
+
     def checkSmoke(self, moduleID=7):
         """获取烟雾状态
 
